==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/DestinationFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.lang.Object;
import java.lang.Boolean;

public interface DestinationFluent<A extends DestinationFluent<A>> extends Fluent<A>{


    public String getHost();
    public A withHost(String host);
    public Boolean hasHost();
    
/**
 * This method has been deprecated, please use method buildPort instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.api.networking.v1alpha3.PortSelector getPort();
    public me.snowdrop.istio.api.networking.v1alpha3.PortSelector buildPort();
    public A withPort(me.snowdrop.istio.api.networking.v1alpha3.PortSelector port);
    public Boolean hasPort();
    public DestinationFluent.PortNested<A> withNewPort();
    public DestinationFluent.PortNested<A> withNewPortLike(me.snowdrop.istio.api.networking.v1alpha3.PortSelector item);
    public DestinationFluent.PortNested<A> editPort();
    public DestinationFluent.PortNested<A> editOrNewPort();
    public DestinationFluent.PortNested<A> editOrNewPortLike(me.snowdrop.istio.api.networking.v1alpha3.PortSelector item);
    public String getSubset();
    public A withSubset(String subset);
    public Boolean hasSubset();

    public interface PortNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,me.snowdrop.istio.api.networking.v1alpha3.PortSelectorFluent<DestinationFluent.PortNested<N>>{

        
    public N and();    public N endPort();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/DestinationFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;

public interface DestinationFluent<A extends DestinationFluent<A>> extends Fluent<A>{


    public String getHost();
    public A withHost(String host);
    public Boolean hasHost();
    public A withNewHost(String arg1);
    public A withNewHost(StringBuilder arg1);
    public A withNewHost(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildPort instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.api.networking.v1alpha3.PortSelector getPort();
    public me.snowdrop.istio.api.networking.v1alpha3.PortSelector buildPort();
    public A withPort(me.snowdrop.istio.api.networking.v1alpha3.PortSelector port);
    public Boolean hasPort();
    public DestinationFluent.PortNested<A> withNewPort();
    public DestinationFluent.PortNested<A> withNewPortLike(me.snowdrop.istio.api.networking.v1alpha3.PortSelector item);
    public DestinationFluent.PortNested<A> editPort();
    public DestinationFluent.PortNested<A> editOrNewPort();
    public DestinationFluent.PortNested<A> editOrNewPortLike(me.snowdrop.istio.api.networking.v1alpha3.PortSelector item);
    public String getSubset();
    public A withSubset(String subset);
    public Boolean hasSubset();
    public A withNewSubset(String arg1);
    public A withNewSubset(StringBuilder arg1);
    public A withNewSubset(StringBuffer arg1);

    public interface PortNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,me.snowdrop.istio.api.networking.v1alpha3.PortSelectorFluent<DestinationFluent.PortNested<N>>{

        
    public N and();    public N endPort();
}


}
